@@ -34,7 +34,7 @@ from jf_ingest.jf_git.exceptions import (
     GitAuthorizationException,
     GitProviderUnavailable,
 )
-from jf_ingest.jf_git.jf_api import get_jf_github_null_user_prs
+from jf_ingest.jf_git.jf_api import get_jf_github_null_user_pr_data
 from jf_ingest.jf_git.standardized_models import (
     StandardizedBranch,
     StandardizedCommit,
@@ -44,6 +44,7 @@ from jf_ingest.jf_git.standardized_models import (
     StandardizedPullRequest,
     StandardizedPullRequestAuthor,
     StandardizedPullRequestMetadata,
+    StandardizedPullRequestReviewAuthor,
     StandardizedRepository,
     StandardizedTeam,
     StandardizedUser,
@@ -90,6 +91,7 @@ class GitObject(Enum):
     GitCommits = "git_data_commits"
     GitPullRequests = "git_data_prs"
     GitPullRequestAuthors = "git_data_pr_authors"
+    GitPullRequestReviewAuthors = "git_data_pr_review_authors"
 
 
 def _generate_git_ingest_event(event_name: str, git_config: GitConfig) -> GitIngestEvent:
@@ -123,6 +125,7 @@ class GitAdapter(ABC):
             | List[StandardizedTeam]
             | List[StandardizedUser]
             | List[StandardizedPullRequestAuthor]
+            | List[StandardizedPullRequestReviewAuthor]
         ),
     ) -> List[Dict]:
         """Helper function for taking a list of objects that inherit from Dataclass and
@@ -397,6 +400,16 @@ class GitAdapter(ABC):
         """
         pass
 
+    @abstractmethod
+    def get_pr_review_authors(
+        self, pr_list: list[StandardizedJFAPIPullRequest]
+    ) -> list[StandardizedPullRequestReviewAuthor]:
+        """Get the review authors of a list of PRs
+
+        This is currently only implemented for GitHub instances
+        """
+        pass
+
     def get_commits_for_repo(
         self, standardized_repo: StandardizedRepository, branches: List[StandardizedBranch]
     ) -> Generator[StandardizedCommit, None, None]:
@@ -981,7 +994,7 @@ class GitAdapter(ABC):
             add_telemetry_fields({'git_pr_count': total_prs})
 
         # For GHC instances, make a request to the JF API to get any PRs that have mannequin authors with
-        # missing user data
+        # missing user data (or missing review authors)
         if (
             git_config.git_provider in [GitProviderInJellyfishRepo.GITHUB, GitProvider.GITHUB]
             and git_config.check_ghc_mannequin_user_prs
@@ -989,7 +1002,10 @@ class GitAdapter(ABC):
             logger.info(
                 f'Checking for any JF PRs with missing mannequin user data for instance {git_config.instance_slug}'
             )
-            prs_with_null_user_data = get_jf_github_null_user_prs(ingest_config, git_config)
+            prs_with_null_user_data = get_jf_github_null_user_pr_data(ingest_config, git_config)
+            prs_with_null_review_data = get_jf_github_null_user_pr_data(
+                ingest_config, git_config, pr_reviews=True
+            )
 
             if prs_with_null_user_data:
                 logger.info(
@@ -1003,8 +1019,19 @@ class GitAdapter(ABC):
                 )
 
                 logger.info(f'Wrote {len(pr_authors)} PR authors to S3/local')
-            else:
-                logger.info('No PRs with missing mannequin user data found')
+
+            if prs_with_null_review_data:
+                logger.info(
+                    f'JF returned {len(prs_with_null_review_data)} PRs with missing mannequin review data'
+                )
+
+                pr_review_authors = self.get_pr_review_authors(prs_with_null_review_data)
+                _write_to_s3_or_local(
+                    object_name=GitObject.GitPullRequestReviewAuthors.value,
+                    json_data=self._transform_data_objects_before_saving(pr_review_authors),
+                )
+
+                logger.info(f'Wrote {len(pr_review_authors)} PR review authors to S3/local')
         else:
             logger.debug(
                 f'Skipping GHC mannequin user PRs check ({git_config.instance_slug}, {git_config.check_ghc_mannequin_user_prs}, {git_config.git_provider})'
