@@ -22,6 +22,7 @@ from jf_ingest.jf_git.standardized_models import (
     StandardizedPullRequestComment,
     StandardizedPullRequestMetadata,
     StandardizedPullRequestReview,
+    StandardizedPullRequestReviewAuthor,
     StandardizedRepository,
     StandardizedTeam,
     StandardizedUser,
@@ -492,7 +493,17 @@ class AzureDevopsAdapter(GitAdapter):
 
         This is currently NOT IMPLEMENTED for ADO instances
         """
-        return []
+        raise NotImplementedError()
+
+    def get_pr_review_authors(
+        self, pr_list: list[StandardizedJFAPIPullRequest]
+    ) -> list[StandardizedPullRequestReviewAuthor]:
+        """
+        Get the review authors of a list of PRs
+
+        This is currently NOT IMPLEMENTED for ADO instances
+        """
+        raise NotImplementedError()
 
 
 '''
