@@ -26,6 +26,7 @@ from jf_ingest.jf_git.standardized_models import (
     StandardizedPullRequestComment,
     StandardizedPullRequestMetadata,
     StandardizedPullRequestReview,
+    StandardizedPullRequestReviewAuthor,
     StandardizedRepository,
     StandardizedShortRepository,
     StandardizedTeam,
@@ -413,6 +414,69 @@ class GithubAdapter(GitAdapter):
         )
         return pr_std_authors
 
+    def get_pr_review_authors(
+        self, pr_list: list[StandardizedJFAPIPullRequest]
+    ) -> list[StandardizedPullRequestReviewAuthor]:
+        """
+        Get the review authors of a list of PRs
+
+        Args:
+            pr_list (list[StandardizedJFAPIPullRequest]): A list of PRs
+        Returns:
+            list[StandardizedPullRequestReviewAuthor]: A list of PR review authors
+        """
+        if not pr_list:
+            return []
+
+        logging_helper.send_to_agent_log_file(
+            msg=f'Pulling PR review authors for {len(pr_list)} PRs',
+            level=logging.INFO,
+        )
+
+        prs_sorted: dict[str, dict[str, list[int]]] = {}
+        pr_std_review_authors: list[StandardizedPullRequestReviewAuthor] = []
+
+        for jf_pr in pr_list:
+            if jf_pr.org_login not in prs_sorted:
+                prs_sorted[jf_pr.org_login] = defaultdict(list)
+
+            prs_sorted[jf_pr.org_login][jf_pr.repo_name].append(jf_pr.pr_number)
+
+        pbar = tqdm(total=len(pr_list), desc='Pulling PR review authors from GQL')
+
+        for org_login, repo_name_to_prs in prs_sorted.items():
+            for repo_name, pr_numbers in repo_name_to_prs.items():
+                try:
+                    query_result = self.client.get_pr_review_authors(
+                        org_login, repo_name, pr_numbers
+                    )
+
+                    for pr_number, prr_dict in query_result.items():
+                        for review_id, user_dict in prr_dict.items():
+                            pr_std_review_authors.append(
+                                _standardize_pr_review_author(
+                                    pr_number, repo_name, org_login, review_id, user_dict
+                                )
+                            )
+                except Exception as e:
+                    logging_helper.send_to_agent_log_file(
+                        msg=f'Error when attempting to pull PR review authors for {org_login}/{repo_name}. Error: {e}',
+                        level=logging.ERROR,
+                    )
+                    logging_helper.send_to_agent_log_file(
+                        traceback.format_exc(), level=logging.ERROR
+                    )
+
+                pbar.update(len(pr_numbers))
+
+        pbar.close()
+
+        logging_helper.send_to_agent_log_file(
+            msg=f'Successfully pulled {len(pr_std_review_authors)} PR review authors from {len(pr_list)} PRs',
+            level=logging.INFO,
+        )
+        return pr_std_review_authors
+
     def git_provider_pr_endpoint_supports_date_filtering(self):
         return False
 
@@ -727,3 +791,22 @@ def _standardize_pr_author(
         user_name=user_dict.get('name'),
         user_email=user_dict.get('email'),
     )
+
+
+def _standardize_pr_review_author(
+    pr_number: int,
+    repo_name: str,
+    org_login: str,
+    review_id: str,
+    user_dict: dict[str, Union[str, None]],
+) -> StandardizedPullRequestReviewAuthor:
+    return StandardizedPullRequestReviewAuthor(
+        pr_number=pr_number,
+        repo_name=repo_name,
+        org_login=org_login,
+        review_id=review_id,
+        user_id=user_dict.get('id'),
+        user_login=user_dict.get('login'),
+        user_name=user_dict.get('name'),
+        user_email=user_dict.get('email'),
+    )
