@@ -22,6 +22,7 @@ from jf_ingest.jf_git.standardized_models import (
     StandardizedPullRequestComment,
     StandardizedPullRequestMetadata,
     StandardizedPullRequestReview,
+    StandardizedPullRequestReviewAuthor,
     StandardizedRepository,
     StandardizedShortRepository,
     StandardizedTeam,
@@ -600,7 +601,17 @@ class GitlabAdapter(GitAdapter):
 
         This is currently NOT IMPLEMENTED for GitLab instances
         """
-        return []
+        raise NotImplementedError()
+
+    def get_pr_review_authors(
+        self, pr_list: list[StandardizedJFAPIPullRequest]
+    ) -> list[StandardizedPullRequestReviewAuthor]:
+        """
+        Get the review authors of a list of PRs
+
+        This is currently NOT IMPLEMENTED for GitLab instances
+        """
+        raise NotImplementedError()
 
     def git_provider_pr_endpoint_supports_date_filtering(self) -> bool:
         """Returns a boolean on if this PR supports time window filtering.
