@@ -1038,6 +1038,133 @@ class GithubClient:
 
         return pr_authors
 
+    def get_pr_review_authors(
+        self, login: str, repo_name: str, pr_ids: list[int]
+    ) -> dict[int, dict[str, dict[str, Union[str, None]]]]:
+        """
+        Get review authors for a list of PRs, keyed by review ID (no pagination; max 50 reviews per PR).
+
+        Returned Format:
+        {
+            pr_number (int): {
+                review_id (str): {
+                    'id': (Optional[str]) gql_id,
+                    'login': (Optional[str]) login,
+                    'name': (Optional[str]) name,
+                    'email': (Optional[str]) email
+                },
+                ...
+            },
+            ...
+        }
+        """
+
+        def _get_pr_review_authors_query_block(pr_number_list: list[int]) -> str:
+            pr_blocks = "\n".join(
+                f"""
+                        pr_{n}: pullRequest(number: {n}) {{
+                            number
+                            reviews(first: 50) {{
+                                nodes {{
+                                    ... on PullRequestReview {{
+                                        id: databaseId
+                                        author {{
+                                            { textwrap.indent(self.github_gql_actor_fragment, " " * 40) }
+                                        }}
+                                    }}
+                                }}
+                            }}
+                        }}
+                """
+                for n in pr_number_list
+            )
+
+            return textwrap.dedent(
+                f"""{{
+                organization(login: "{login}") {{
+                    repo: repository(name: "{repo_name}") {{
+                        {pr_blocks}
+                    }}
+                }}
+            }}
+            """
+            ).strip()
+
+        pr_review_authors: dict[int, dict[str, dict[str, Union[str, None]]]] = {}
+
+        for number_batch in batch_iterable(pr_ids, 100):
+            continue_search = True
+            process_batch = True
+            current_pr_numbers = number_batch.copy()
+            attempt_count = 0
+            result: Optional[dict] = None
+
+            while continue_search and attempt_count < 3:
+                attempt_count += 1
+                try:
+                    result = self.get_raw_result(
+                        _get_pr_review_authors_query_block(current_pr_numbers)
+                    )
+                    continue_search = False
+                except GitHubGQLNotFoundError as e:
+                    logger.warning('Not all PRs found, removing missing PRs from query')
+
+                    for err in e.error_response:
+                        try:
+                            pr_num_str = err.get('path', [])[-1]
+                            pr_num = int(pr_num_str.split('_')[-1])
+                            logger.info(f'Removing PR {pr_num} from query')
+                            current_pr_numbers.remove(pr_num)
+                        except Exception as e:
+                            logger.warning(f'Error removing PR {err} from query: {e}')
+
+                    if not current_pr_numbers:
+                        logger.info('No PRs left to query, stopping')
+                        continue_search = False
+                        process_batch = False
+                except Exception as e:
+                    logger.error(f'GQL error querying PR review authors: {e}')
+                    continue_search = False
+                    process_batch = False
+
+            if not process_batch or not result:
+                logger.error('Unable to process PR review authors for PR number batch, skipping')
+                continue
+
+            for _, pr_data in result['data']['organization']['repo'].items():
+                pr_number = pr_data['number']
+                review_map: dict[str, dict[str, Union[str, None]]] = {}
+
+                for review in pr_data.get('reviews', {}).get('nodes', []):
+                    if not review:
+                        logger.warning(f'No reviews found for PR {pr_number} with data: {pr_data}')
+                        continue
+
+                    prr_actor = review.get('author')
+                    if not prr_actor:
+                        logger.warning(f'No author found for review {review.get("id")}')
+                        continue
+
+                    review_id = review.get('id')
+                    review_id = str(review_id) if review_id is not None else None
+                    if not review_id:
+                        logger.warning(f'No ID found for review: {review}')
+                        continue
+
+                    a_id = prr_actor.get('id')
+                    a_id = str(a_id) if a_id else None
+
+                    review_map[review_id] = {
+                        'id': a_id,
+                        'login': prr_actor.get('login'),
+                        'name': prr_actor.get('name'),
+                        'email': prr_actor.get('email'),
+                    }
+
+                pr_review_authors[pr_number] = review_map
+
+        return pr_review_authors
+
     # PR query is HUGE, see above GITHUB_GQL_PR_* blocks for reused code
     # page_size is optimally variable. Most repos only have a 0 to a few PRs day to day,
     # so sometimes the optimal page_size is 0. Generally, we should never go over 25
