@@ -2,7 +2,7 @@ import json
 import logging
 import time
 from datetime import datetime
-from typing import Any, Dict, Generator, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Generator, List, Optional, Tuple, Union
 from urllib.parse import urlparse
 
 import gitlab
@@ -306,6 +306,31 @@ class GitlabClient:
                 )
                 break
 
+    def page_results(
+        self, gitlab_function: Callable, starting_page: int = 1, page_size: int = 100, **kwargs
+    ) -> Generator[Project | RESTObject, None, None]:
+        """
+        This is a helper function for paging results from a gitlab function. This is done to prevent
+        ChunkedEncodingErrors from being uncaught when using the `iterator=True` kwarg.
+
+        Args:
+            gitlab_function (Callable): A Gitlab library function to be called with pagination.
+            starting_page (int): Page to start from when returning items. 1 is the first page. Defaults to 1.
+            page_size (int): Page size to use in kwargs of function. Defaults to 100.
+
+        Yields:
+            Generator[dict, None, None]: This function yields each item from all the pages paged, item by item
+        """
+        kwargs['page'] = starting_page
+        kwargs['per_page'] = page_size
+        while True:
+            results = retry_for_status(gitlab_function, statuses_to_retry=GITLAB_STATUSES_TO_RETRY, **kwargs)  # type: ignore
+            if not results:
+                break
+            for result in results:
+                yield result
+            kwargs['page'] += 1
+
     def get_path_value(self, path_value: str, data_dict: Optional[dict] = None) -> Optional[Any]:
         """
         This function takes a path value separated by periods to determine nesting in a dict. This will be primarily
@@ -352,11 +377,11 @@ class GitlabClient:
                 self.client.groups.get, jf_org.login, statuses_to_retry=GITLAB_STATUSES_TO_RETRY
             )
 
-            kwargs_dict: dict[str, Union[bool, str]] = {'iterator': True, 'include_subgroups': True}
+            kwargs_dict: dict[str, Any] = {'include_subgroups': True}
             if only_private:
                 kwargs_dict['visibility'] = 'private'
 
-            for repo in retry_for_status(group.projects.list, statuses_to_retry=GITLAB_STATUSES_TO_RETRY, **kwargs_dict):  # type: ignore
+            for repo in self.page_results(group.projects.list, **kwargs_dict):
                 yield repo
         except (requests.exceptions.ConnectionError, GitlabError, RetryLimitExceeded) as e:
             logger.warning(
@@ -365,7 +390,7 @@ class GitlabClient:
 
     def get_repos_count(self, login: str, only_private: Optional[bool] = False) -> int:
         url = f"{self.rest_api_url}/api/v4/groups/{login}/projects"
-        params: dict[str, Union[str, int]] = {'per_page': 1}
+        params: dict[str, Any] = {'per_page': 1}
 
         if only_private:
             params['visibility'] = 'private'
@@ -391,12 +416,7 @@ class GitlabClient:
             self.client.projects.get, project_id, statuses_to_retry=GITLAB_STATUSES_TO_RETRY
         )
 
-        # We use pagination here instead of using the iterator kwarg. The generator bypasses our retry_for_status check.
-        # We can get ChunkedEncodingErrors, which is handled by retry_for_status.
-        kwargs_dict: dict[str, Any] = {
-            'page': 1,
-            'per_page': 100,
-        }
+        kwargs_dict: dict[str, Any] = {}
         if branch_name:
             kwargs_dict['ref_name'] = branch_name
         if since:
@@ -405,13 +425,8 @@ class GitlabClient:
             kwargs_dict['until'] = until
 
         try:
-            while True:
-                commits = retry_for_status(project.commits.list, statuses_to_retry=GITLAB_STATUSES_TO_RETRY, **kwargs_dict)  # type: ignore
-                if not commits:
-                    break
-                for commit in commits:
-                    yield commit
-                kwargs_dict['page'] += 1
+            for commit in self.page_results(project.commits.list, **kwargs_dict):
+                yield commit
 
         except (requests.exceptions.ConnectionError, GitlabError, RetryLimitExceeded) as e:
             logger.warning(
@@ -438,7 +453,7 @@ class GitlabClient:
         )
         branches_list: List[ProjectBranch | RESTObject] = []
 
-        kwargs_dict: dict[str, Any] = {'iterator': True}
+        kwargs_dict: dict[str, Any] = {}
         if branch_name:
             try:
                 branches_list.append(project.branches.get(branch_name))
@@ -453,8 +468,7 @@ class GitlabClient:
                     # We technically could use regex here to reduce extra hits, but we're not guaranteed to have regex
                     # on very old versions of GitLab's api. Limit this to 10 per page, likely to have a hit there.
                     kwargs_dict['search'] = branch_name
-                    kwargs_dict['per_page'] = 10
-                    branches = retry_for_status(project.branches.list, statuses_to_retry=GITLAB_STATUSES_TO_RETRY, **kwargs_dict)  # type: ignore
+                    branches = self.page_results(project.branches.list, page_size=10, **kwargs_dict)
 
                     # If we're given a branch name, we only expect one branch back. We *may* get more than one, so just
                     # return the first we get that completely matches the branch name.
@@ -486,12 +500,8 @@ class GitlabClient:
             yield branch
 
     def get_organizations_rest_api(self) -> Generator[Group | RESTObject, None, None]:
-        kwargs_dict: dict[str, Any] = {'iterator': True, 'query_data': {'all_available': True}}
-        groups = retry_for_status(
-            self.client.groups.list, statuses_to_retry=GITLAB_STATUSES_TO_RETRY, **kwargs_dict
-        )
-
-        for group in groups:
+        kwargs_dict: dict[str, Any] = {'query_data': {'all_available': True}}
+        for group in self.page_results(self.client.groups.list, **kwargs_dict):
             if getattr(group, 'parent_id', None) is None:
                 yield group
 
@@ -564,15 +574,9 @@ class GitlabClient:
             group = retry_for_status(
                 self.client.groups.get, group_id, statuses_to_retry=GITLAB_STATUSES_TO_RETRY
             )
-
-            for user in retry_for_status(
-                group.members.list,
-                all=True,
-                iterator=True,
-                statuses_to_retry=GITLAB_STATUSES_TO_RETRY,
-                max_retries_for_retry_for_status=3,
-            ):
+            for user in self.page_results(group.members.list):
                 yield user
+
         except Exception as e:
             logging_helper.send_to_agent_log_file(
                 f'When attempting to get user data we ran in the following exception: {e}. '
