@@ -490,24 +490,14 @@ def _run_load_and_push_to_s3(ingest_config: IngestionConfig) -> bool:
     # First create test connection with v3 to check JQL Enhanced Search availability
     #######################################################################
 
-    # Calculate API selection decision first
-    should_attempt_enhanced_search = jira_config.feature_flags.get(
-        Constants.JQL_ENHANCED_SEARCH_ENABLED, False
-    ) and not jira_config.feature_flags.get(Constants.FORCE_LEGACY_API, False)
-
-    # Create test connection with v3 if we should attempt enhanced search
-    use_jql_enhanced_search = False
-    if should_attempt_enhanced_search:
-        try:
-            test_connection = get_jira_connection(
-                config=jira_config,
-                auth_method=JiraAuthMethod.BasicAuth,
-                use_jql_enhanced_search=True,
-            )
-            use_jql_enhanced_search = is_jql_enhanced_search_available(test_connection)
-        except Exception as e:
-            logger.warning(f"Failed to create v3 test connection for JQL Enhanced Search: {e}")
-            use_jql_enhanced_search = False
+    # Test if JQL Enhanced Search is available
+    use_jql_enhanced_search = is_jql_enhanced_search_available(
+        jira_config=jira_config,
+        jql_enhanced_search_enabled=jira_config.feature_flags.get(
+            Constants.JQL_ENHANCED_SEARCH_ENABLED, False
+        ),
+        force_legacy_api=jira_config.feature_flags.get(Constants.FORCE_LEGACY_API, False),
+    )
 
     # Create final connections with appropriate API version
     jira_basic_connection = get_jira_connection(
